var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var MetaModel = require("../metamodel");
var Sys = require("./systemTypes");
var Params = require("./parameters");
var Common = require("./common");
var MimeType = (function (_super) {
    __extends(MimeType, _super);
    function MimeType() {
        _super.apply(this, arguments);
        this.$ = [MetaModel.description("This sub type of the string represents mime types")];
    }
    MimeType.prototype.isForm = function () {
        if (this.value() == "application/x-www-form-urlencoded" || this.value() == 'multipart/form-data') {
            return true;
        }
        return false;
    };
    MimeType.prototype.isXML = function () {
        if (this.value() == "application/xml") {
            return true;
        }
        return false;
    };
    MimeType.prototype.isJSON = function () {
        if (this.value() == "application/json") {
            return true;
        }
        return false;
    };
    return MimeType;
})(Sys.StringType);
exports.MimeType = MimeType;
var BodyLike = (function (_super) {
    __extends(BodyLike, _super);
    function BodyLike() {
        _super.apply(this, arguments);
        this.$name = [MetaModel.key(), MetaModel.description("Mime type of the request or response body"), MetaModel.canInherit("mediaType"), MetaModel.oftenKeys(["application/json", "application/xml",
                "application/x-www-form-urlencoded",
                "multipart/form-data"])];
        this.$schema = [
            MetaModel.requireValue("this.name.isForm()", "false"), MetaModel.description("\n    The structure of a request or response body MAY be further specified by the schema property under the appropriate media type.\n\nThe schema key CANNOT be specified if a body's media type is application/x-www-form-urlencoded or multipart/form-data.\n\nAll parsers of RAML MUST be able to interpret JSON Schema [JSON_SCHEMA] and XML Schema [XML_SCHEMA].\n\nSchema MAY be declared inline or in an external file. However, if the schema is sufficiently large so as to make it difficult for a person to read the API definition, or the schema is reused across multiple APIs or across multiple miles in the same API, the !include user-defined data type SHOULD be used instead of including the content inline.\nAlternatively, the value of the schema field MAY be the name of a schema specified in the root-level schemas property (see Named Parameters, or it MAY be declared in an external file and included by using the by using the RAML !include user-defined data type.")];
        this.$example = [
            MetaModel.description("Documentation generators MUST use body properties' example attributes to generate example invocations.\nThis example shows example attributes for two body property media types.")];
        this.$formParameters = [MetaModel.setsContextValue("location", Params.ParameterLocation.FORM), MetaModel.description("Web forms REQUIRE special encoding and custom declaration.\nIf the API's media type is either application/x-www-form-urlencoded or multipart/form-data, the formParameters property MUST specify the name-value pairs that the API is expecting.\nThe formParameters property is a map in which the key is the name of the web form parameter, and the value is itself a map the specifies the web form parameter's attributes")];
        this.$ = [MetaModel.canInherit("mediaType")];
        this.$schemaContent = [MetaModel.customHandling(), MetaModel.description("Returns schema content for the cases when schema is inlined, when schema is included, and when schema is a reference.")];
    }
    return BodyLike;
})(Common.RAMLLanguageElement);
exports.BodyLike = BodyLike;
var XMLBody = (function (_super) {
    __extends(XMLBody, _super);
    function XMLBody() {
        _super.apply(this, arguments);
        this.$schema = [MetaModel.description("XSD Schema")];
        this.$ = [MetaModel.functionalDescriminator("this.mime.isXML()"), MetaModel.description("Needed to set connection between xml related mime types and xsd schema")];
    }
    return XMLBody;
})(BodyLike);
exports.XMLBody = XMLBody;
var JSONBody = (function (_super) {
    __extends(JSONBody, _super);
    function JSONBody() {
        _super.apply(this, arguments);
        this.$schema = [MetaModel.description("JSON Schema")];
        this.$ = [MetaModel.functionalDescriminator("this.mime.isJSON()"), MetaModel.description("Needed to set connection between json related mime types and json schema")
        ];
    }
    return JSONBody;
})(BodyLike);
exports.JSONBody = JSONBody;
var Response = (function (_super) {
    __extends(Response, _super);
    function Response() {
        _super.apply(this, arguments);
        this.$code = [MetaModel.key(), MetaModel.extraMetaKey("statusCodes"), MetaModel.description("Responses MUST be a map of one or more HTTP status codes, where each status code itself is a map that describes that status code.")];
        this.$headers = [MetaModel.setsContextValue("location", Params.ParameterLocation.HEADERS), MetaModel.newInstanceName("New Header"),
            MetaModel.description("An API's methods may support custom header values in responses. The custom, non-standard HTTP headers MUST be specified by the headers property.\n        API's may include the the placeholder token {?} in a header name to indicate that any number of headers that conform to the specified format can be sent in responses. This is particularly useful for APIs that allow HTTP headers that conform to some naming convention to send arbitrary, custom data.\n\nIn the following example, the header x-metadata-{?} is used to send metadata that has been saved with the media.")];
        this.$body = [MetaModel.newInstanceName("New Body"), MetaModel.description("Each response MAY contain a body property, which conforms to the same structure as request body properties (see Body). Responses that can return more than one response code MAY therefore have multiple bodies defined.\nFor APIs without a priori knowledge of the response types for their responses, \"*/*\" MAY be used to indicate that responses that do not matching other defined data types MUST be accepted. Processing applications MUST match the most descriptive media type first if \"*/*\" is used.")];
    }
    return Response;
})(Common.RAMLLanguageElement);
exports.Response = Response;
//# sourceMappingURL=bodies.js.map