var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var MetaModel = require("../metamodel");
var Sys = require("./systemTypes");
var Params = require("./parameters");
var Common = require("./common");
var ResourceTypeRef = (function (_super) {
    __extends(ResourceTypeRef, _super);
    function ResourceTypeRef() {
        _super.apply(this, arguments);
        this.$resourceType = [MetaModel.customHandling(), MetaModel.description("Returns referenced resource type")];
    }
    return ResourceTypeRef;
})(Sys.Reference);
exports.ResourceTypeRef = ResourceTypeRef;
var TraitRef = (function (_super) {
    __extends(TraitRef, _super);
    function TraitRef() {
        _super.apply(this, arguments);
        this.$trait = [MetaModel.customHandling(), MetaModel.description("Returns referenced trait")];
    }
    return TraitRef;
})(Sys.Reference);
exports.TraitRef = TraitRef;
var MethodBase = (function (_super) {
    __extends(MethodBase, _super);
    function MethodBase() {
        _super.apply(this, arguments);
        this.$responses = [MetaModel.newInstanceName("New Response"), MetaModel.description("Resource methods MAY have one or more responses. Responses MAY be described using the description property, and MAY include example attributes or schema properties.\n")];
        this.$body = [MetaModel.newInstanceName("New Body"), MetaModel.description("Some method verbs expect the resource to be sent as a request body. For example, to create a resource, the request must include the details of the resource to create.\nResources CAN have alternate representations. For example, an API might support both JSON and XML representations.\nA method's body is defined in the body property as a hashmap, in which the key MUST be a valid media type.")];
        this.$protocols = [MetaModel.oneOf(["HTTP", "HTTPS"]),
            MetaModel.description("A method can override an API's protocols value for that single method by setting a different value for the fields.")];
        this.$ = [MetaModel.description("Method object allows description of http methods")];
        this.$securedBy = [
            MetaModel.allowNull(),
            MetaModel.description("A list of the security schemas to apply, these must be defined in the securitySchemes declaration.\nTo indicate that the method may be called without applying any securityScheme, the method may be annotated with the null securityScheme.\nSecurity schemas may also be applied to a resource with securedBy, which is equivalent to applying the security schemas to all methods that may be declared, explicitly or implicitly, by defining the resourceTypes or traits property for that resource.")];
    }
    return MethodBase;
})(Params.HasNormalParameters);
exports.MethodBase = MethodBase;
var Trait = (function (_super) {
    __extends(Trait, _super);
    function Trait() {
        _super.apply(this, arguments);
        this.$usage = [MetaModel.description("Instructions on how and when the trait should be used.")];
        this.$name = [MetaModel.key(), MetaModel.description("Name of the trait")];
        this.$ = [MetaModel.inlinedTemplates(), MetaModel.allowQuestion()];
        this.$parametrizedProperties = [
            MetaModel.customHandling(),
            MetaModel.description("Returns object representation of parametrized properties of the trait")
        ];
    }
    return Trait;
})(MethodBase);
exports.Trait = Trait;
var ResourceType = (function (_super) {
    __extends(ResourceType, _super);
    function ResourceType() {
        _super.apply(this, arguments);
        this.$usage = [MetaModel.description("Instructions on how and when the resource type should be used.")];
        this.$name = [MetaModel.key(), MetaModel.description("Name of the resource type")];
        this.$methods = [MetaModel.description("Methods that are part of this resource type definition")];
        this.$is = [MetaModel.description("Instantiation of applyed traits")];
        this.$type = [MetaModel.description("Instantiation of applyed resource type")];
        this.$ = [MetaModel.inlinedTemplates(), MetaModel.allowQuestion()];
        this.$securedBy = [
            MetaModel.allowNull(),
            MetaModel.description(" securityScheme may also be applied to a resource by using the securedBy key, which is equivalent to applying the securityScheme to all methods that may be declared, explicitly or implicitly, by defining the resourceTypes or traits property for that resource.\nTo indicate that the method may be called without applying any securityScheme, the method may be annotated with the null securityScheme.")];
        this.$uriParameters = [
            MetaModel.setsContextValue("location", Params.ParameterLocation.URI),
            MetaModel.description("Uri parameters of this resource")];
        this.$displayName = [MetaModel.description("An alternate, human-friendly name for the resource type")];
        this.$baseUriParameters = [MetaModel.setsContextValue("fieldOrParam", true), MetaModel.setsContextValue("location", Params.ParameterLocation.BURI), MetaModel.description("A resource or a method can override a base URI template's values. This is useful to restrict or change the default or parameter selection in the base URI. The baseUriParameters property MAY be used to override any or all parameters defined at the root level baseUriParameters property, as well as base URI parameters not specified at the root level.")];
        this.$parametrizedProperties = [
            MetaModel.customHandling(),
            MetaModel.description("Returns object representation of parametrized properties of the resource type")
        ];
    }
    return ResourceType;
})(Common.RAMLLanguageElement);
exports.ResourceType = ResourceType;
var Method = (function (_super) {
    __extends(Method, _super);
    function Method() {
        _super.apply(this, arguments);
        this.$method = [MetaModel.key(),
            MetaModel.extraMetaKey("methods"),
            MetaModel.oneOf(["get", "put", "post", "delete", "patch", "options", "head", "trace", "connect"]), MetaModel.description("Method that can be called")];
        this.$securedBy = [
            MetaModel.allowNull(),
            MetaModel.description(" securityScheme may also be applied to a resource by using the securedBy key, which is equivalent to applying the securityScheme to all methods that may be declared, explicitly or implicitly, by defining the resourceTypes or traits property for that resource.\nTo indicate that the method may be called without applying any securityScheme, the method may be annotated with the null securityScheme.")];
        this.$is = [MetaModel.description("Instantiation of applyed traits")];
        this.$baseUriParameters = [MetaModel.setsContextValue("fieldOrParam", true), MetaModel.setsContextValue("location", Params.ParameterLocation.BURI), MetaModel.description("A resource or a method can override a base URI template's values. This is useful to restrict or change the default or parameter selection in the base URI. The baseUriParameters property MAY be used to override any or all parameters defined at the root level baseUriParameters property, as well as base URI parameters not specified at the root level.")];
    }
    return Method;
})(MethodBase);
exports.Method = Method;
var Resource = (function (_super) {
    __extends(Resource, _super);
    function Resource() {
        _super.apply(this, arguments);
        this.$relativeUri = [MetaModel.key(),
            MetaModel.startFrom("/"), MetaModel.description("Relative URL of this resource from the parent resource"),
        ];
        this.$type = [MetaModel.description("Instantiation of applyed resource type")];
        this.$is = [MetaModel.description("Instantiation of applyed traits")];
        this.$securedBy = [
            MetaModel.allowNull(),
            MetaModel.description(" securityScheme may also be applied to a resource by using the securedBy key, which is equivalent to applying the securityScheme to all methods that may be declared, explicitly or implicitly, by defining the resourceTypes or traits property for that resource.\nTo indicate that the method may be called without applying any securityScheme, the method may be annotated with the null securityScheme.")];
        this.$uriParameters = [
            MetaModel.setsContextValue("fieldOrParam", true),
            MetaModel.setsContextValue("location", Params.ParameterLocation.URI),
            MetaModel.description("Uri parameters of this resource")];
        this.$methods = [MetaModel.newInstanceName("New Method"), MetaModel.description("Methods that can be called on this resource")];
        this.$resources = [MetaModel.newInstanceName("New Resource"), MetaModel.description("Children resources")];
        this.$displayName = [MetaModel.description("An alternate, human-friendly name for the resource")];
        this.$baseUriParameters = [MetaModel.setsContextValue("fieldOrParam", true), MetaModel.setsContextValue("location", Params.ParameterLocation.BURI), MetaModel.description("A resource or a method can override a base URI template's values. This is useful to restrict or change the default or parameter selection in the base URI. The baseUriParameters property MAY be used to override any or all parameters defined at the root level baseUriParameters property, as well as base URI parameters not specified at the root level.")];
    }
    return Resource;
})(Common.RAMLLanguageElement);
exports.Resource = Resource;
var SecuritySchemePart = (function (_super) {
    __extends(SecuritySchemePart, _super);
    function SecuritySchemePart() {
        _super.apply(this, arguments);
        this.$headers = [
            MetaModel.markdownDescription("Optional array of headers, documenting the possible headers that could be accepted."),
            MetaModel.valueDescription("Object whose property names are the request header names and whose values describe the values.")
        ];
        this.$queryParameters = [
            MetaModel.markdownDescription("Query parameters, used by the schema in order to authorize the request. Mutually exclusive with queryString."),
            MetaModel.valueDescription("Object whose property names are the query parameter names and whose values describe the values.")
        ];
        this.$queryString = [
            MetaModel.description("Specifies the query string, used by the schema in order to authorize the request. Mutually exclusive with queryParameters."),
            MetaModel.valueDescription("Type name or type declaration")
        ];
        this.$responses = [
            MetaModel.description("Optional array of responses, describing the possible responses that could be sent.")
        ];
        this.$is = [MetaModel.hide()];
        this.$securedBy = [MetaModel.hide()];
        this.$displayName = [MetaModel.description("An alternate, human-friendly name for the security scheme part")];
        this.$description = [
            MetaModel.description("A longer, human-friendly description of the security scheme part"),
            MetaModel.valueDescription("Markdown string")
        ];
        this.$annotations = [MetaModel.description("Annotations to be applied to this security scheme part. Annotations are any property whose key begins with \"(\" and ends with \")\" and whose name (the part between the beginning and ending parentheses) is a declared annotation name. See [[raml-10-spec-annotations|the section on annotations]].")];
    }
    return SecuritySchemePart;
})(MethodBase);
exports.SecuritySchemePart = SecuritySchemePart;
var SecuritySchemeSettings = (function () {
    function SecuritySchemeSettings() {
        this.$ = [MetaModel.allowAny()];
    }
    return SecuritySchemeSettings;
})();
exports.SecuritySchemeSettings = SecuritySchemeSettings;
var AbstractSecurityScheme = (function (_super) {
    __extends(AbstractSecurityScheme, _super);
    function AbstractSecurityScheme() {
        _super.apply(this, arguments);
        this.$name = [
            MetaModel.key(),
            MetaModel.startFrom(""),
            MetaModel.hide(),
            MetaModel.description("Name of the security scheme")
        ];
        this.$type = [
            MetaModel.required(),
            MetaModel.oneOf(["OAuth 1.0", "OAuth 2.0", "Basic Authentication", "DigestSecurityScheme Authentication", "x-{other}"]),
            MetaModel.descriminatingProperty(),
            MetaModel.description("The securitySchemes property MUST be used to specify an API's security mechanisms, including the required settings and the authentication methods that the API supports. one authentication method is allowed if the API supports them."),
            MetaModel.valueDescription("string<br><br>The value MUST be one of<br>* OAuth 1.0,<br>* OAuth 2.0,<br>* BasicSecurityScheme Authentication<br>* DigestSecurityScheme Authentication<br>* x-&lt;other&gt;")
        ];
        this.$description = [
            MetaModel.description("The description attribute MAY be used to describe a security schemes property."),
            MetaModel.description("The description MAY be used to describe a securityScheme.")
        ];
        this.$describedBy = [
            MetaModel.description("A description of the request components related to Security that are determined by the scheme: the headers, query parameters or responses. As a best practice, even for standard security schemes, API designers SHOULD describe these properties of security schemes.\nIncluding the security scheme description completes an API documentation.")
        ];
        this.$settings = [MetaModel.description("The settings attribute MAY be used to provide security scheme-specific information. The required attributes vary depending on the type of security scheme is being declared.\nIt describes the minimum set of properties which any processing application MUST provide and validate if it chooses to implement the security scheme. Processing applications MAY choose to recognize other properties for things such as token lifetime, preferred cryptographic algorithms, and more.")];
        this.$ = [MetaModel.description("Declares globally referable security schema definition"), MetaModel.actuallyExports("$self"), MetaModel.referenceIs("settings")];
    }
    return AbstractSecurityScheme;
})(Common.RAMLLanguageElement);
exports.AbstractSecurityScheme = AbstractSecurityScheme;
var SecuritySchemeRef = (function (_super) {
    __extends(SecuritySchemeRef, _super);
    function SecuritySchemeRef() {
        _super.apply(this, arguments);
        this.$ = [MetaModel.allowAny()];
        this.$securitySchemeName = [MetaModel.customHandling(), MetaModel.description("Returns the name of security scheme, this reference refers to.")];
        this.$securityScheme = [MetaModel.customHandling(), MetaModel.description("Returns AST node of security scheme, this reference refers to, or null.")];
    }
    return SecuritySchemeRef;
})(Sys.Reference);
exports.SecuritySchemeRef = SecuritySchemeRef;
var OAuth1SecuritySchemeSettings = (function (_super) {
    __extends(OAuth1SecuritySchemeSettings, _super);
    function OAuth1SecuritySchemeSettings() {
        _super.apply(this, arguments);
        this.$ = [MetaModel.allowAny(), MetaModel.functionalDescriminator("$parent.type=='OAuth 1.0'")];
        this.$requestTokenUri = [
            MetaModel.required(),
            MetaModel.description("The URI of the Temporary Credential Request endpoint as defined in RFC5849 Section 2.1"),
            MetaModel.valueDescription("FixedUriString")
        ];
        this.$authorizationUri = [
            MetaModel.required(),
            MetaModel.description("The URI of the Resource Owner Authorization endpoint as defined in RFC5849 Section 2.2"),
            MetaModel.valueDescription("FixedUriString")
        ];
        this.$tokenCredentialsUri = [
            MetaModel.required(),
            MetaModel.description("The URI of the Token Request endpoint as defined in RFC5849 Section 2.3"),
            MetaModel.valueDescription("FixedUriString")
        ];
        this.$annotations = [MetaModel.hide()];
    }
    return OAuth1SecuritySchemeSettings;
})(SecuritySchemeSettings);
exports.OAuth1SecuritySchemeSettings = OAuth1SecuritySchemeSettings;
var OAuth2SecuritySchemeSettings = (function (_super) {
    __extends(OAuth2SecuritySchemeSettings, _super);
    function OAuth2SecuritySchemeSettings() {
        _super.apply(this, arguments);
        this.$ = [MetaModel.allowAny()];
        this.$accessTokenUri = [
            MetaModel.required(),
            MetaModel.description("The URI of the Token Endpoint as defined in RFC6749 [RFC6748] Section 3.2. Not required forby implicit grant type."),
            MetaModel.valueDescription("FixedUriString")
        ];
        this.$authorizationUri = [
            MetaModel.required(),
            MetaModel.description("The URI of the Authorization Endpoint as defined in RFC6749 [RFC6748] Section 3.1. Required forby authorization_code and implicit grant types."),
            MetaModel.valueDescription("FixedUriString")
        ];
        this.$authorizationGrants = [
            MetaModel.description("A list of the Authorization grants supported by the API as defined in RFC6749 [RFC6749] Sections 4.1, 4.2, 4.3 and 4.4, can be any of:\n - authorization_code\n - password\n - client_credentials\n - implicit\n - refresh_token."),
            MetaModel.markdownDescription("A list of the Authorization grants supported by the API as defined in RFC6749 [RFC6749] Sections 4.1, 4.2, 4.3 and 4.4, can be any of:<br>* authorization_code<br>* password<br>* client_credentials<br>* implicit<br>* refresh_token."),
        ];
        this.$scopes = [MetaModel.description("A list of scopes supported by the security scheme as defined in RFC6749 [RFC6749] Section 3.3")];
        this.$annotations = [MetaModel.hide()];
    }
    return OAuth2SecuritySchemeSettings;
})(SecuritySchemeSettings);
exports.OAuth2SecuritySchemeSettings = OAuth2SecuritySchemeSettings;
var OAuth2SecurityScheme = (function (_super) {
    __extends(OAuth2SecurityScheme, _super);
    function OAuth2SecurityScheme() {
        _super.apply(this, arguments);
        this.type = "OAuth 2.0";
        this.$ = [MetaModel.description("Declares globally referable security schema definition"), MetaModel.actuallyExports("$self"), MetaModel.referenceIs("settings")];
    }
    return OAuth2SecurityScheme;
})(AbstractSecurityScheme);
var OAuth1SecurityScheme = (function (_super) {
    __extends(OAuth1SecurityScheme, _super);
    function OAuth1SecurityScheme() {
        _super.apply(this, arguments);
        this.type = "OAuth 1.0";
        this.$ = [MetaModel.description("Declares globally referable security schema definition"), MetaModel.actuallyExports("$self"), MetaModel.referenceIs("settings")];
    }
    return OAuth1SecurityScheme;
})(AbstractSecurityScheme);
var BasicSecurityScheme = (function (_super) {
    __extends(BasicSecurityScheme, _super);
    function BasicSecurityScheme() {
        _super.apply(this, arguments);
        this.type = "Basic Authentication";
        this.$ = [MetaModel.description("Declares globally referable security schema definition"), MetaModel.actuallyExports("$self"), MetaModel.referenceIs("settings")];
    }
    return BasicSecurityScheme;
})(AbstractSecurityScheme);
var DigestSecurityScheme = (function (_super) {
    __extends(DigestSecurityScheme, _super);
    function DigestSecurityScheme() {
        _super.apply(this, arguments);
        this.type = "Digest Authentication";
        this.$ = [MetaModel.description("Declares globally referable security schema definition"), MetaModel.actuallyExports("$self"), MetaModel.referenceIs("settings")];
    }
    return DigestSecurityScheme;
})(AbstractSecurityScheme);
var CustomSecurityScheme = (function (_super) {
    __extends(CustomSecurityScheme, _super);
    function CustomSecurityScheme() {
        _super.apply(this, arguments);
        this.type = "x-{other}";
        this.$ = [MetaModel.description("Declares globally referable security schema definition"), MetaModel.actuallyExports("$self"), MetaModel.referenceIs("settings")];
    }
    return CustomSecurityScheme;
})(AbstractSecurityScheme);
//# sourceMappingURL=methodsAndResources.js.map