var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var MetaModel = require("../metamodel");
var Params = require("./parameters");
var Common = require("./common");
var RAMLSpec;
(function (RAMLSpec) {
    var GlobalSchema = (function (_super) {
        __extends(GlobalSchema, _super);
        function GlobalSchema() {
            _super.apply(this, arguments);
            this.$key = [MetaModel.key(), MetaModel.description("Name of the global schema, used to refer on schema content")];
            this.$value = [MetaModel.description("Content of the schema"), MetaModel.value()];
            this.$ = [MetaModel.actuallyExports("value"), MetaModel.description("Content of the schema")];
        }
        return GlobalSchema;
    })(Common.RAMLSimpleElement);
    RAMLSpec.GlobalSchema = GlobalSchema;
    var Api = (function (_super) {
        __extends(Api, _super);
        function Api() {
            _super.apply(this, arguments);
            this.$title = [MetaModel.required(), MetaModel.description("The title property is a short plain text description of the RESTful API. " +
                    "The title property's value SHOULD be suitable for use as a title for the contained user documentation.")];
            this.$version = [MetaModel.description("If the RAML API definition is targeted to a specific API version, the API definition MUST contain a version property. The version property is OPTIONAL and should not be used if:\nThe API itself is not versioned.\nThe API definition does not change between versions. The API architect can decide whether a change to user documentation elements, but no change to the API's resources, constitutes a version change.\nThe API architect MAY use any versioning scheme so long as version numbers retain the same format. For example, \"v3\", \"v3.0\", and \"V3\" are all allowed, but are not considered to be equal.")];
            this.$baseUri = [MetaModel.description("(Optional during development; Required after implementation) A RESTful API's resources are defined relative to the API's base URI. The use of the baseUri field is OPTIONAL to allow describing APIs that have not yet been implemented. After the API is implemented (even a mock implementation) and can be accessed at a service endpoint, the API definition MUST contain a baseUri property. The baseUri property's value MUST conform to the URI specification [RFC2396] or a Level 1 Template URI as defined in RFC 6570 [RFC6570].\n            The baseUri property SHOULD only be used as a reference value. API client generators MAY make the baseUri configurable by the API client's users.\n            If the baseUri value is a Level 1 Template URI, the following reserved base URI parameters are available for replacement:")
            ];
            this.$baseUriParameters = [MetaModel.setsContextValue("location", Params.ParameterLocation.BURI), MetaModel.description("Base uri parameters are named parameters which described template parameters in the base uri")];
            this.$uriParameters = [MetaModel.setsContextValue("location", Params.ParameterLocation.BURI), MetaModel.description("URI parameters can be further defined by using the uriParameters property. " +
                    "The use of uriParameters is OPTIONAL. The uriParameters property MUST be a map in which each key MUST be the name of the URI parameter as defined in the baseUri property. " +
                    "The uriParameters CANNOT contain a key named version because it is a reserved URI parameter name. The value of the uriParameters property is itself a map that specifies  the property's attributes as named parameters")];
            this.$protocols = [MetaModel.oneOf(["HTTP", "HTTPS"]),
                MetaModel.description("A RESTful API can be reached HTTP, HTTPS, or both. The protocols property MAY be used to specify the protocols that an API supports. If the protocols property is not specified, the protocol specified at the baseUri property is used. The protocols property MUST be an array of strings, of values `HTTP` and/or `HTTPS`.")];
            this.$mediaType = [
                MetaModel.oftenKeys(["application/json", "application/xml",
                    "application/x-www-form-urlencoded",
                    "multipart/formdata"]),
                MetaModel.description("(Optional) The media types returned by API responses, and expected from API requests that accept a body, MAY be defaulted by specifying the mediaType property. This property is specified at the root level of the API definition. The property's value MAY be a single string with a valid media type:\nOne of the following YAML media types:\ntext/yaml\ntext/x-yaml\napplication/yaml\napplication/x-yaml*\nAny type from the list of IANA MIME Media Types, http://www.iana.org/assignments/media-types\nA custom type that conforms to the regular expression, \"application/[A-Za-z.-0-1]*+?(json|xml)\"\nFor any combination of resource and operation in the API, if a media type is specified as a key of the body property for that resource and operation, or if a media type is specified in the mediaType property, the body MUST be in the specified media types. Moreover, if the client specifies an Accepts header containing multiple media types that are allowed by the specification for the requested resource and operation, the server SHOULD return a body using the media type in the Accepts header's mediaType list.\n"), MetaModel.inherited()];
            this.$schemas = [MetaModel.embeddedInMaps(), MetaModel.description("To better achieve consistency and simplicity, the API definition SHOULD include an OPTIONAL schemas property in the root section. The schemas property specifies collections of schemas that could be used anywhere in the API definition. The value of the schemas property is an array of maps; in each map, the keys are the schema name, and the values are schema definitions. The schema definitions MAY be included inline or by using the RAML !include user-defined data type.")];
            this.$traits = [MetaModel.embeddedInMaps(), MetaModel.description("Declarations of traits used in this API")];
            this.$securedBy = [MetaModel.allowNull(), MetaModel.description("A list of the security schemas to apply to all methods, these must be defined in the securitySchemes declaration.")];
            this.$securitySchemes = [MetaModel.embeddedInMaps(), MetaModel.description("Security schemas that can be applied with securedBy")];
            this.$resourceTypes = [MetaModel.embeddedInMaps(), MetaModel.description("Declaration of resource types used in this API")];
            this.$resources = [MetaModel.newInstanceName("New Resource"), MetaModel.description("Resources are identified by their relative URI, which MUST begin with a slash (/).\nA resource defined as a root-level property is called a top-level resource. Its property's key is the resource's URI relative to the baseUri.\nA resource defined as a child property of another resource is called a nested resource, and its property's key is its URI relative to its parent resource's URI.\nEvery property whose key begins with a slash (/), and is either at the root of the API definition or is the child property of a resource property, is a resource property. The key of a resource, i.e. its relative URI, MAY consist of multiple URI path fragments separated by slashes; e.g. \"/bom/items\" may indicate the collection of items in a bill of materials as a single resource. However, if the individual URI path fragments are themselves resources, the API definition SHOULD use nested resources to describe this structure; e.g. if \"/bom\" is itself a resource then \"/items\" should be a nested resource of \"/bom\", while \"/bom/items\" should not be used.")];
            this.$documentation = [MetaModel.description("The API definition can include a variety of documents that serve as a user guides and reference documentation for the API. Such documents can clarify how the API works or provide business context.\n            Documentation-generators MUST include all the sections in an API definition's documentation property in the documentation output, and they MUST preserve the order in which the documentation is declared.\n            To add user documentation to the API, include the documentation property at the root of the API definition. The documentation property MUST be an array of documents. Each document MUST contain title and content attributes, both of which are REQUIRED. If the documentation property is specified, it MUST include at least one document.\n            Documentation-generators MUST process the content field as if it was defined using Markdown [MARKDOWN].\n\n        This example shows an API definition with a single user document.")];
            this.$RAMLVersion = [MetaModel.customHandling(), MetaModel.description("Returns AST node of security scheme, this reference refers to, or null.")];
        }
        return Api;
    })(Common.RAMLLanguageElement);
    var DocumentationItem = (function (_super) {
        __extends(DocumentationItem, _super);
        function DocumentationItem() {
            _super.apply(this, arguments);
            this.$title = [MetaModel.description("title of documentation section"), MetaModel.required()];
            this.$content = [MetaModel.description("Content of documentation section"), MetaModel.required()];
        }
        return DocumentationItem;
    })(Common.RAMLSimpleElement);
})(RAMLSpec || (RAMLSpec = {}));
//# sourceMappingURL=api.js.map