import Sys = require("./systemTypes");
import Params = require("./parameters");
import Bodies = require("./bodies");
import Common = require("./common");
export declare class ResourceTypeRef extends Sys.Reference<ResourceType> {
    resourceType: ResourceType;
    $resourceType: void[];
}
export declare class TraitRef extends Sys.Reference<Trait> {
    trait: Trait;
    $trait: void[];
}
export declare class MethodBase extends Params.HasNormalParameters {
    responses: Bodies.Response[];
    $responses: void[];
    body: Bodies.BodyLike[];
    $body: void[];
    protocols: string[];
    $protocols: void[];
    $: void[];
    securedBy: SecuritySchemeRef[];
    $securedBy: void[];
}
export declare class Trait extends MethodBase implements Sys.DeclaresDynamicType<Trait> {
    name: string;
    usage: string;
    $usage: void[];
    $name: void[];
    $: void[];
    parametrizedProperties: Sys.TypeInstance;
    $parametrizedProperties: void[];
}
export declare class ResourceType extends Common.RAMLLanguageElement implements Sys.DeclaresDynamicType<ResourceType> {
    name: string;
    usage: string;
    $usage: void[];
    $name: void[];
    methods: Method[];
    $methods: void[];
    is: TraitRef[];
    $is: void[];
    type: ResourceTypeRef;
    $type: void[];
    $: void[];
    securedBy: SecuritySchemeRef[];
    $securedBy: void[];
    uriParameters: Params.Parameter[];
    $uriParameters: void[];
    displayName: string;
    $displayName: void[];
    baseUriParameters: Params.Parameter[];
    $baseUriParameters: void[];
    parametrizedProperties: Sys.TypeInstance;
    $parametrizedProperties: void[];
}
export declare class Method extends MethodBase {
    method: string;
    $method: void[];
    securedBy: SecuritySchemeRef[];
    $securedBy: void[];
    is: TraitRef[];
    $is: void[];
    baseUriParameters: Params.Parameter[];
    $baseUriParameters: void[];
}
export declare class Resource extends Common.RAMLLanguageElement {
    relativeUri: Sys.RelativeUriString;
    $relativeUri: void[];
    type: ResourceTypeRef;
    $type: void[];
    is: TraitRef[];
    $is: void[];
    securedBy: SecuritySchemeRef[];
    $securedBy: void[];
    uriParameters: Params.Parameter[];
    $uriParameters: void[];
    methods: Method[];
    $methods: void[];
    resources: Resource[];
    $resources: void[];
    displayName: string;
    $displayName: void[];
    baseUriParameters: Params.Parameter[];
    $baseUriParameters: void[];
}
export declare class SecuritySchemePart extends MethodBase {
    $headers: void[];
    $queryParameters: void[];
    $queryString: void[];
    $responses: void[];
    $is: void[];
    $securedBy: void[];
    $displayName: void[];
    $description: void[];
    $annotations: void[];
}
export declare class SecuritySchemeSettings {
    $: void[];
}
export declare class AbstractSecurityScheme extends Common.RAMLLanguageElement implements Sys.Referencable<AbstractSecurityScheme> {
    name: string;
    $name: void[];
    type: string;
    $type: void[];
    description: Sys.MarkdownString;
    $description: void[];
    describedBy: SecuritySchemePart;
    $describedBy: void[];
    settings: SecuritySchemeSettings;
    $settings: void[];
    $: void[];
}
export declare class SecuritySchemeRef extends Sys.Reference<AbstractSecurityScheme> {
    $: void[];
    securitySchemeName: string;
    $securitySchemeName: void[];
    securityScheme: AbstractSecurityScheme;
    $securityScheme: void[];
}
export declare class OAuth1SecuritySchemeSettings extends SecuritySchemeSettings {
    $: void[];
    requestTokenUri: Sys.FixedUri;
    $requestTokenUri: void[];
    authorizationUri: Sys.FixedUri;
    $authorizationUri: void[];
    tokenCredentialsUri: Sys.FixedUri;
    $tokenCredentialsUri: void[];
    $annotations: void[];
}
export declare class OAuth2SecuritySchemeSettings extends SecuritySchemeSettings {
    $: void[];
    accessTokenUri: Sys.FixedUri;
    $accessTokenUri: void[];
    authorizationUri: Sys.FixedUri;
    $authorizationUri: void[];
    authorizationGrants: string[];
    $authorizationGrants: void[];
    scopes: string[];
    $scopes: void[];
    $annotations: void[];
}
