var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var MetaModel = require("../metamodel");
var Common = require("./common");
var index = {
    title: "Named Parameters"
};
(function (ParameterLocation) {
    ParameterLocation[ParameterLocation["QUERY"] = 0] = "QUERY";
    ParameterLocation[ParameterLocation["HEADERS"] = 1] = "HEADERS";
    ParameterLocation[ParameterLocation["URI"] = 2] = "URI";
    ParameterLocation[ParameterLocation["FORM"] = 3] = "FORM";
    ParameterLocation[ParameterLocation["BURI"] = 4] = "BURI";
})(exports.ParameterLocation || (exports.ParameterLocation = {}));
var ParameterLocation = exports.ParameterLocation;
var Parameter = (function (_super) {
    __extends(Parameter, _super);
    function Parameter() {
        _super.apply(this, arguments);
        this.$name = [MetaModel.key(), MetaModel.description("name of the parameter"), MetaModel.extraMetaKey("headers")];
        this.$displayName = [MetaModel.description("An alternate, human-friendly name for the parameter")];
        this.$type = [MetaModel.defaultValue("string"), MetaModel.descriminatingProperty(), MetaModel.description("The type attribute specifies the primitive type of the parameter's resolved value. " +
                "API clients MUST return/throw an error if the parameter's resolved value does not match the specified type. If type is not specified, it defaults to string."), MetaModel.canBeDuplicator()];
        this.$location = [MetaModel.system(), MetaModel.description("Location of the parameter (can not be edited by user)")];
        this.$required = [MetaModel.description("Set to true if parameter is required"),
            MetaModel.defaultBooleanValue(true)];
        this.$default = [MetaModel.description("The default attribute specifies the default value to use for the property if the property is omitted or its value is not specified." +
                " This SHOULD NOT be interpreted as a requirement for the client to send the default attribute's value if there is no other value to send. " +
                "Instead, the default attribute's value is the value the server uses if the client does not send a value.")];
        this.$example = [MetaModel.description("(Optional) The example attribute shows an example value for the property." +
                " This can be used, e.g., by documentation generators to generate sample values for the property.")];
        this.$repeat = [MetaModel.description("The repeat attribute specifies that the parameter can be repeated. " +
                "If the parameter can be used multiple times, the repeat parameter value MUST be set to 'true'. Otherwise, the default value is 'false' and the parameter may not be repeated."),
            MetaModel.defaultBooleanValue(false)];
        this.$ = [];
    }
    return Parameter;
})(Common.RAMLLanguageElement);
exports.Parameter = Parameter;
var StringTypeDeclaration = (function (_super) {
    __extends(StringTypeDeclaration, _super);
    function StringTypeDeclaration() {
        _super.apply(this, arguments);
        this.$pattern = [
            MetaModel.description("(Optional, applicable only for parameters of type string) The pattern attribute is a regular expression that a parameter of type string MUST match. Regular expressions MUST follow the regular expression specification from ECMA 262/Perl 5. The pattern MAY be enclosed in double quotes for readability and clarity.")];
        this.$enum = [
            MetaModel.description("(Optional, applicable only for parameters of type string) The enum attribute provides an enumeration of the parameter's valid values. This MUST be an array. If the enum attribute is defined, API clients and servers MUST verify that a parameter's value matches a value in the enum array. If there is no matching value, the clients and servers MUST treat this as an error.")];
        this.$minLength = [
            MetaModel.description("(Optional, applicable only for parameters of type string) The minLength attribute specifies the parameter value's minimum number of characters.")];
        this.$maxLength = [MetaModel.description("(Optional, applicable only for parameters of type string) The maxLength attribute specifies the parameter value's maximum number of characters.")];
        this.type = "string";
        this.$ = [MetaModel.description("Value must be a string")];
    }
    return StringTypeDeclaration;
})(Parameter);
exports.StringTypeDeclaration = StringTypeDeclaration;
var BooleanTypeDeclaration = (function (_super) {
    __extends(BooleanTypeDeclaration, _super);
    function BooleanTypeDeclaration() {
        _super.apply(this, arguments);
        this.type = "boolean";
        this.$ = [MetaModel.description("Value must be a boolean")];
    }
    return BooleanTypeDeclaration;
})(Parameter);
exports.BooleanTypeDeclaration = BooleanTypeDeclaration;
var NumberTypeDeclaration = (function (_super) {
    __extends(NumberTypeDeclaration, _super);
    function NumberTypeDeclaration() {
        _super.apply(this, arguments);
        this.type = "number";
        this.$minimum = [MetaModel.description("(Optional, applicable only for parameters of type number or integer) The minimum attribute specifies the parameter's minimum value.")];
        this.$maximum = [MetaModel.description("(Optional, applicable only for parameters of type number or integer) The maximum attribute specifies the parameter's maximum value.")];
        this.$ = [MetaModel.description("Value MUST be a number. Indicate floating point numbers as defined by YAML.")];
    }
    return NumberTypeDeclaration;
})(Parameter);
exports.NumberTypeDeclaration = NumberTypeDeclaration;
var IntegerTypeDeclaration = (function (_super) {
    __extends(IntegerTypeDeclaration, _super);
    function IntegerTypeDeclaration() {
        _super.apply(this, arguments);
        this.type = "integer";
        this.$ = [MetaModel.description("Value MUST be a integer.")];
    }
    return IntegerTypeDeclaration;
})(NumberTypeDeclaration);
exports.IntegerTypeDeclaration = IntegerTypeDeclaration;
var DateTypeDeclaration = (function (_super) {
    __extends(DateTypeDeclaration, _super);
    function DateTypeDeclaration() {
        _super.apply(this, arguments);
        this.type = "date";
        this.$ = [MetaModel.description("Value MUST be a string representation of a date as defined in RFC2616 Section 3.3 [RFC2616]. "),
        ];
    }
    return DateTypeDeclaration;
})(Parameter);
exports.DateTypeDeclaration = DateTypeDeclaration;
var FileTypeDeclaration = (function (_super) {
    __extends(FileTypeDeclaration, _super);
    function FileTypeDeclaration() {
        _super.apply(this, arguments);
        this.type = "file";
        this.$ = [MetaModel.requireValue("location", ParameterLocation.FORM),
            MetaModel.description("(Applicable only to Form properties) Value is a file. Client generators SHOULD use this type to handle file uploads correctly.")];
    }
    return FileTypeDeclaration;
})(Parameter);
exports.FileTypeDeclaration = FileTypeDeclaration;
var HasNormalParameters = (function (_super) {
    __extends(HasNormalParameters, _super);
    function HasNormalParameters() {
        _super.apply(this, arguments);
        this.$displayName = [MetaModel.description("An alternate, human-readable name of the object")];
        this.$queryParameters = [
            MetaModel.setsContextValue("location", ParameterLocation.QUERY), MetaModel.newInstanceName("New query parameter"), MetaModel.description('An APIs resources MAY be filtered (to return a subset of results) or altered (such as transforming' +
                ' a response body from JSON to XML format) by the use of query strings. If the resource or its method supports a query string, the query string MUST be defined by the queryParameters property')];
        this.$headers = [
            MetaModel.setsContextValue("location", ParameterLocation.HEADERS),
            MetaModel.description("Headers that allowed at this position"),
            MetaModel.newInstanceName("New Header"),
        ];
    }
    return HasNormalParameters;
})(Common.RAMLLanguageElement);
exports.HasNormalParameters = HasNormalParameters;
//# sourceMappingURL=parameters.js.map