import Sys = require("./systemTypes");
import Common = require("./common");
export declare enum ModelLocation {
    QUERY = 0,
    HEADERS = 1,
    URI = 2,
    FORM = 3,
    BURI = 4,
    ANNOTATION = 5,
    MODEL = 6,
    SECURITYSCHEMATYPE = 7,
}
export declare enum LocationKind {
    APISTRUCTURE = 0,
    DECLARATIONS = 1,
    MODELS = 2,
}
export declare class ExampleSpec extends Common.RAMLLanguageElement {
    content: string;
    $content: void[];
    structuredContent: TypeInstance;
    $structuredContent: void[];
    strict: boolean;
    $strict: void[];
    name: string;
    $name: void[];
    $displayName: void[];
    $description: void[];
    $annotations: void[];
}
export declare class DataElementProperty {
    name: string;
    $name: void[];
    location: ModelLocation;
    $location: void[];
    locationKind: LocationKind;
    $locationKind: void[];
    default: string;
    $default: void[];
    required: boolean;
    $required: void[];
}
export declare class TypeDeclaration extends Common.RAMLLanguageElement {
    name: string;
    $name: void[];
    facets: TypeDeclaration[];
    $facets: void[];
    fixedFacets: TypeInstance;
    $fixedFacets: void[];
    schema: string;
    $schema: void[];
    schemaContent: string;
    $schemaContent: void[];
    type: string;
    $type: void[];
    location: ModelLocation;
    $location: void[];
    locationKind: LocationKind;
    $locationKind: void[];
    default: any;
    $default: void[];
    example: string;
    $example: void[];
    structuredExample: TypeInstance;
    $structuredExample: void[];
    examples: ExampleSpec[];
    $examples: void[];
    repeat: boolean;
    $repeat: void[];
    required: boolean;
    $required: void[];
    $: void[];
    $displayName: void[];
    $description: void[];
    $annotations: void[];
}
export declare class ScalarElement {
    facets: TypeDeclaration[];
    $facets: void[];
    enum: string[];
    $enum: void[];
}
export declare class ArrayTypeDeclaration extends TypeDeclaration {
    type: string;
    uniqueItems: boolean;
    $uniqueItems: void[];
    items: TypeDeclaration;
    $items: void[];
    minItems: number;
    $minItems: void[];
    maxItems: number;
    $maxItems: void[];
    $: void[];
}
export declare class UnionTypeDeclaration extends TypeDeclaration {
    discriminator: string;
    $discriminator: void[];
    type: string;
    $: void[];
}
export declare class ObjectTypeDeclaration extends TypeDeclaration {
    properties: TypeDeclaration[];
    $properties: void[];
    minProperties: number;
    $minProperties: void[];
    maxProperties: number;
    $maxProperties: void[];
    additionalProperties: TypeDeclaration;
    $additionalProperties: void[];
    patternProperties: TypeDeclaration[];
    $patternProperties: void[];
    discriminator: string;
    $discriminator: void[];
    discriminatorValue: string;
    $discriminatorValue: void[];
    type: string;
    $type: void[];
    $: void[];
}
export declare class StringTypeDeclaration extends TypeDeclaration {
    pattern: string;
    $pattern: void[];
    minLength: number;
    $minLength: void[];
    maxLength: number;
    $maxLength: void[];
    type: string;
    $: void[];
    enum: string[];
    $enum: void[];
}
export declare class BooleanTypeDeclaration extends TypeDeclaration {
    type: string;
    $: void[];
}
export declare class ValueTypeDeclaration extends TypeDeclaration {
    type: string;
    $: void[];
}
export declare class NumberTypeDeclaration extends TypeDeclaration {
    type: string;
    minimum: number;
    $minimum: void[];
    maximum: number;
    $maximum: void[];
    $: void[];
    enum: string[];
    $enum: void[];
    format: string;
    $format: void[];
    multipleOf: number;
    $multipleOf: void[];
}
export declare class IntegerTypeDeclaration extends NumberTypeDeclaration {
    type: string;
    $: void[];
    format: string;
    $format: void[];
}
export declare class RAMLExpression extends TypeDeclaration {
    type: string;
    $: void[];
}
export declare class SchemaElement extends TypeDeclaration {
    $: void[];
    type: string;
}
export declare class DateTypeDeclaration extends TypeDeclaration {
    type: string;
    $: void[];
    dateFormat: Sys.DateFormatSpec;
}
export declare class TypeInstance {
    $: void[];
    properties: TypeInstanceProperty[];
    $properties: void[];
    isScalar: boolean;
    $isScalar: void[];
    value: any;
    $value: void[];
}
export declare class TypeInstanceProperty {
    $: void[];
    name: string;
    $name: void[];
    value: TypeInstance;
    $value: void[];
    values: TypeInstance[];
    $values: void[];
    isArray: boolean;
    $isArray: void[];
}
