var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var MetaModel = require("../metamodel");
var Sys = require("./systemTypes");
var Params = require("./parameters");
var Common = require("./common");
var models = require("./datamodel");
var ResourceTypeRef = (function (_super) {
    __extends(ResourceTypeRef, _super);
    function ResourceTypeRef() {
        _super.apply(this, arguments);
        this.$resourceType = [MetaModel.customHandling(), MetaModel.description("Returns referenced resource type")];
    }
    return ResourceTypeRef;
})(Sys.Reference);
exports.ResourceTypeRef = ResourceTypeRef;
var TraitRef = (function (_super) {
    __extends(TraitRef, _super);
    function TraitRef() {
        _super.apply(this, arguments);
        this.$trait = [MetaModel.customHandling(), MetaModel.description("Returns referenced trait")];
    }
    return TraitRef;
})(Sys.Reference);
exports.TraitRef = TraitRef;
var SecuritySchemePart = (function (_super) {
    __extends(SecuritySchemePart, _super);
    function SecuritySchemePart() {
        _super.apply(this, arguments);
        this.$headers = [
            MetaModel.markdownDescription("Optional array of headers, documenting the possible headers that could be accepted. See [[raml-10-spec-headers|Headers]] section."),
            MetaModel.valueDescription("Object whose property names are the request header names and whose values describe the values.")
        ];
        this.$queryParameters = [
            MetaModel.markdownDescription("Query parameters, used by the scheme in order to authorize the request. Mutually exclusive with queryString. See [[raml-10-spec-query-parameters-in-a-query-string|Query Parameters]] section."),
            MetaModel.valueDescription("Object whose property names are the query parameter names and whose values describe the values.")
        ];
        this.$queryString = [
            MetaModel.description("Specifies the query string, used by the scheme in order to authorize the request. Mutually exclusive with queryParameters."),
            MetaModel.valueDescription("Type name or type declaration")
        ];
        this.$responses = [
            MetaModel.description("Optional array of responses, describing the possible responses that could be sent. See [[raml-10-spec-responses|Responses]] section.")
        ];
        this.$is = [MetaModel.hide()];
        this.$securedBy = [MetaModel.hide()];
        this.$displayName = [MetaModel.description("An alternate, human-friendly name for the security scheme part")];
        this.$description = [
            MetaModel.description("A longer, human-friendly description of the security scheme part"),
            MetaModel.valueDescription("Markdown string")
        ];
        this.$annotations = [MetaModel.description("Annotations to be applied to this security scheme part. Annotations are any property whose key begins with \"(\" and ends with \")\" and whose name (the part between the beginning and ending parentheses) is a declared annotation name. See [[raml-10-spec-annotations|the section on annotations]].")];
    }
    return SecuritySchemePart;
})(MethodBase);
exports.SecuritySchemePart = SecuritySchemePart;
var SecuritySchemeSettings = (function () {
    function SecuritySchemeSettings() {
        this.$ = [MetaModel.allowAny()];
    }
    return SecuritySchemeSettings;
})();
exports.SecuritySchemeSettings = SecuritySchemeSettings;
var OAuth1SecuritySchemeSettings = (function (_super) {
    __extends(OAuth1SecuritySchemeSettings, _super);
    function OAuth1SecuritySchemeSettings() {
        _super.apply(this, arguments);
        this.$ = [MetaModel.allowAny(), MetaModel.functionalDescriminator("$parent.type=='OAuth 1.0'")];
        this.$requestTokenUri = [
            MetaModel.required(),
            MetaModel.description("The URI of the Temporary Credential Request endpoint as defined in RFC5849 Section 2.1"),
            MetaModel.valueDescription("FixedUriString")
        ];
        this.$authorizationUri = [
            MetaModel.required(),
            MetaModel.description("The URI of the Resource Owner Authorization endpoint as defined in RFC5849 Section 2.2"),
            MetaModel.valueDescription("FixedUriString")
        ];
        this.$tokenCredentialsUri = [
            MetaModel.required(),
            MetaModel.description("The URI of the Token Request endpoint as defined in RFC5849 Section 2.3"),
            MetaModel.valueDescription("FixedUriString")
        ];
        this.$signatures = [
            MetaModel.oneOf(["HMAC-SHA1", "RSA-SHA1", "PLAINTEXT"]),
            MetaModel.hide(),
            MetaModel.description("List of the signature methods used by the server. Available methods: HMAC-SHA1, RSA-SHA1, PLAINTEXT")
        ];
    }
    return OAuth1SecuritySchemeSettings;
})(SecuritySchemeSettings);
exports.OAuth1SecuritySchemeSettings = OAuth1SecuritySchemeSettings;
var OAuth2SecuritySchemeSettings = (function (_super) {
    __extends(OAuth2SecuritySchemeSettings, _super);
    function OAuth2SecuritySchemeSettings() {
        _super.apply(this, arguments);
        this.$ = [MetaModel.allowAny()];
        this.$accessTokenUri = [
            MetaModel.required(),
            MetaModel.description("The URI of the Token Endpoint as defined in RFC6749 [RFC6748] Section 3.2. Not required forby implicit grant type."),
            MetaModel.valueDescription("FixedUriString")
        ];
        this.$authorizationUri = [
            MetaModel.required(),
            MetaModel.description("The URI of the Authorization Endpoint as defined in RFC6749 [RFC6748] Section 3.1. Required forby authorization_code and implicit grant types."),
            MetaModel.valueDescription("FixedUriString")
        ];
        this.$authorizationGrants = [
            MetaModel.required(),
            MetaModel.description("A list of the Authorization grants supported by the API as defined in RFC6749 [RFC6749] Sections 4.1, 4.2, 4.3 and 4.4, can be any of:\n - authorization_code\n - password\n - client_credentials\n - implicit\n - refresh_token."),
            MetaModel.markdownDescription("A list of the Authorization grants supported by the API as defined in RFC6749 [RFC6749] Sections 4.1, 4.2, 4.3 and 4.4, can be any of:<br>* authorization_code<br>* password<br>* client_credentials<br>* implicit<br>* refresh_token."),
        ];
        this.$scopes = [MetaModel.description("A list of scopes supported by the security scheme as defined in RFC6749 [RFC6749] Section 3.3")];
    }
    return OAuth2SecuritySchemeSettings;
})(SecuritySchemeSettings);
exports.OAuth2SecuritySchemeSettings = OAuth2SecuritySchemeSettings;
var PassThroughSecuritySchemeSettings = (function (_super) {
    __extends(PassThroughSecuritySchemeSettings, _super);
    function PassThroughSecuritySchemeSettings() {
        _super.apply(this, arguments);
        this.$ = [MetaModel.allowAny()];
        this.$queryParameterName = [MetaModel.description("Name of query parameter used to pass key")];
        this.$headerName = [MetaModel.description("Name of header used to pass key")];
    }
    return PassThroughSecuritySchemeSettings;
})(SecuritySchemeSettings);
exports.PassThroughSecuritySchemeSettings = PassThroughSecuritySchemeSettings;
var SecuritySchemeRef = (function (_super) {
    __extends(SecuritySchemeRef, _super);
    function SecuritySchemeRef() {
        _super.apply(this, arguments);
        this.$securitySchemeName = [MetaModel.customHandling(), MetaModel.description("Returns the name of security scheme, this reference refers to.")];
        this.$securityScheme = [MetaModel.customHandling(), MetaModel.description("Returns AST node of security scheme, this reference refers to, or null.")];
    }
    return SecuritySchemeRef;
})(Sys.Reference);
exports.SecuritySchemeRef = SecuritySchemeRef;
var AbstractSecurityScheme = (function (_super) {
    __extends(AbstractSecurityScheme, _super);
    function AbstractSecurityScheme() {
        _super.apply(this, arguments);
        this.$name = [
            MetaModel.key(),
            MetaModel.startFrom(""),
            MetaModel.hide(),
            MetaModel.description("Name of the security scheme")
        ];
        this.$type = [
            MetaModel.required(),
            MetaModel.oneOf(["OAuth 1.0", "OAuth 2.0", "Basic Authentication", "Digest Authentication", "Pass Through", "x-{other}"]),
            MetaModel.descriminatingProperty(),
            MetaModel.description("The securitySchemes property MUST be used to specify an API's security mechanisms, including the required settings and the authentication methods that the API supports. one authentication method is allowed if the API supports them."),
            MetaModel.valueDescription("string<br><br>The value MUST be one of<br>* OAuth 1.0,<br>* OAuth 2.0,<br>* BasicSecurityScheme Authentication<br>* DigestSecurityScheme Authentication<br>* Pass Through<br>* x-&lt;other&gt;")
        ];
        this.$description = [
            MetaModel.description("The description attribute MAY be used to describe a security schemes property."),
            MetaModel.description("The description MAY be used to describe a securityScheme.")
        ];
        this.$describedBy = [
            MetaModel.description("A description of the request components related to Security that are determined by the scheme: the headers, query parameters or responses. As a best practice, even for standard security schemes, API designers SHOULD describe these properties of security schemes.\nIncluding the security scheme description completes an API documentation.")
        ];
        this.$settings = [MetaModel.description("The settings attribute MAY be used to provide security scheme-specific information. The required attributes vary depending on the type of security scheme is being declared.\nIt describes the minimum set of properties which any processing application MUST provide and validate if it chooses to implement the security scheme. Processing applications MAY choose to recognize other properties for things such as token lifetime, preferred cryptographic algorithms, and more.")];
        this.$ = [MetaModel.description("Declares globally referable security scheme definition"), MetaModel.actuallyExports("$self"), MetaModel.referenceIs("settings")];
    }
    return AbstractSecurityScheme;
})(Common.RAMLLanguageElement);
exports.AbstractSecurityScheme = AbstractSecurityScheme;
var OAuth2SecurityScheme = (function (_super) {
    __extends(OAuth2SecurityScheme, _super);
    function OAuth2SecurityScheme() {
        _super.apply(this, arguments);
        this.type = "OAuth 2.0";
        this.$ = [MetaModel.description("Declares globally referable security scheme definition"), MetaModel.actuallyExports("$self"), MetaModel.referenceIs("settings")];
    }
    return OAuth2SecurityScheme;
})(AbstractSecurityScheme);
var OAuth1SecurityScheme = (function (_super) {
    __extends(OAuth1SecurityScheme, _super);
    function OAuth1SecurityScheme() {
        _super.apply(this, arguments);
        this.type = "OAuth 1.0";
        this.$ = [MetaModel.description("Declares globally referable security scheme definition"), MetaModel.actuallyExports("$self"), MetaModel.referenceIs("settings")];
    }
    return OAuth1SecurityScheme;
})(AbstractSecurityScheme);
var PassThroughSecurityScheme = (function (_super) {
    __extends(PassThroughSecurityScheme, _super);
    function PassThroughSecurityScheme() {
        _super.apply(this, arguments);
        this.type = "Pass Through";
        this.$ = [MetaModel.description("Declares globally referable security scheme definition"), MetaModel.actuallyExports("$self"), MetaModel.referenceIs("settings")];
    }
    return PassThroughSecurityScheme;
})(AbstractSecurityScheme);
var BasicSecurityScheme = (function (_super) {
    __extends(BasicSecurityScheme, _super);
    function BasicSecurityScheme() {
        _super.apply(this, arguments);
        this.type = "Basic Authentication";
        this.$ = [MetaModel.description("Declares globally referable security scheme definition"), MetaModel.actuallyExports("$self"), MetaModel.referenceIs("settings")];
    }
    return BasicSecurityScheme;
})(AbstractSecurityScheme);
var DigestSecurityScheme = (function (_super) {
    __extends(DigestSecurityScheme, _super);
    function DigestSecurityScheme() {
        _super.apply(this, arguments);
        this.type = "Digest Authentication";
        this.$ = [MetaModel.description("Declares globally referable security scheme definition"), MetaModel.actuallyExports("$self"), MetaModel.referenceIs("settings")];
    }
    return DigestSecurityScheme;
})(AbstractSecurityScheme);
var CustomSecurityScheme = (function (_super) {
    __extends(CustomSecurityScheme, _super);
    function CustomSecurityScheme() {
        _super.apply(this, arguments);
        this.type = "x-{other}";
        this.$ = [MetaModel.description("Declares globally referable security scheme definition"), MetaModel.actuallyExports("$self"), MetaModel.referenceIs("settings")];
    }
    return CustomSecurityScheme;
})(AbstractSecurityScheme);
var MethodBase = (function (_super) {
    __extends(MethodBase, _super);
    function MethodBase() {
        _super.apply(this, arguments);
        this.$responses = [
            MetaModel.setsContextValue("response", "true"),
            MetaModel.newInstanceName("New Response"),
            MetaModel.description("Information about the expected responses to a request"),
            MetaModel.valueDescription("An object whose keys are the HTTP status codes of the responses and whose values describe the responses.")
        ];
        this.$body = [MetaModel.newInstanceName("New Body"), MetaModel.description("Some method verbs expect the resource to be sent as a request body. For example, to create a resource, the request must include the details of the resource to create.\nResources CAN have alternate representations. For example, an API might support both JSON and XML representations.\nA method's body is defined in the body property as a hashmap, in which the key MUST be a valid media type.")];
        this.$protocols = [MetaModel.oneOf(["HTTP", "HTTPS"]),
            MetaModel.description("A method can override the protocols specified in the resource or at the API root, by employing this property."),
            MetaModel.valueDescription("array of strings of value HTTP or HTTPS, or a single string of such kind, case-insensitive")
        ];
        this.$securedBy = [
            MetaModel.allowNull(),
            MetaModel.description(" securityScheme may also be applied to a resource by using the securedBy key, which is equivalent to applying the securityScheme to all methods that may be declared, explicitly or implicitly, by defining the resourceTypes or traits property for that resource.\nTo indicate that the method may be called without applying any securityScheme, the method may be annotated with the null securityScheme.")];
        this.$is = [MetaModel.description("Instantiation of applyed traits")];
    }
    return MethodBase;
})(Params.HasNormalParameters);
exports.MethodBase = MethodBase;
var Trait = (function (_super) {
    __extends(Trait, _super);
    function Trait() {
        _super.apply(this, arguments);
        this.$usage = [MetaModel.description("Instructions on how and when the trait should be used.")];
        this.$name = [MetaModel.key(), MetaModel.description("Name of the trait")];
        this.$ = [MetaModel.inlinedTemplates(), MetaModel.allowQuestion()];
        this.$uses = [
            MetaModel.embeddedInMaps(),
            MetaModel.description("You may import library locally here it contents is accessible only inside of this trait"),
            MetaModel.setsContextValue("decls", "true"),
            MetaModel.valueDescription("An array of libraries or a single library")
        ];
        this.$parametrizedProperties = [
            MetaModel.customHandling(),
            MetaModel.description("Returns object representation of parametrized properties of the trait")
        ];
    }
    return Trait;
})(MethodBase);
exports.Trait = Trait;
var ResourceBase = (function (_super) {
    __extends(ResourceBase, _super);
    function ResourceBase() {
        _super.apply(this, arguments);
        this.$methods = [
            MetaModel.description("Methods that are part of this resource type definition"),
            MetaModel.markdownDescription("The methods available on this resource. See [[raml-10-spec-methods|the section on method properties]]."),
            MetaModel.documentationTableLabel("get?<br>patch?<br>put?<br>post?<br>delete?<br>options?<br>head?<br>trace?<br>connect?"),
            MetaModel.valueDescription("Object describing the method")
        ];
        this.$is = [
            MetaModel.description("A list of the traits to apply to all methods declared (implicitly or explicitly) for this resource. See [[raml-10-spec-applying-resource-types-and-traits|Applying Resource Types and Traits]] section. Individual methods may override this declaration"),
            MetaModel.valueDescription("array, which can contain each of the following elements:<br>* name of unparametrized trait<br>* a key-value pair with trait name as key and a map of trait parameters as value<br>* inline trait declaration<br><br>(or a single element of any above kind)")
        ];
        this.$type = [
            MetaModel.description("The resource type which this resource inherits. . See [[raml-10-spec-applying-resource-types-and-traits|Applying Resource Types and Traits]] section."),
            MetaModel.valueDescription("one of the following elements:<br>* name of unparametrized resource type<br>* a key-value pair with resource type name as key and a map of its parameters as value<br>* inline resource type declaration")
        ];
        this.$securedBy = [
            MetaModel.allowNull(),
            MetaModel.description("The security schemes that apply to all methods declared (implicitly or explicitly) for this resource."),
            MetaModel.valueDescription("array of security scheme names or a single security scheme name")
        ];
        this.$uriParameters = [
            MetaModel.setsContextValue("location", models.ModelLocation.URI),
            MetaModel.setsContextValue("locationKind", models.LocationKind.APISTRUCTURE),
            MetaModel.setsContextValue("fieldOrParam", true),
            MetaModel.description("Detailed information about any URI parameters of this resource"),
            MetaModel.valueDescription("object whose property names are the URI parameter names and whose values describe the values")
        ];
    }
    return ResourceBase;
})(Common.RAMLLanguageElement);
exports.ResourceBase = ResourceBase;
var ResourceType = (function (_super) {
    __extends(ResourceType, _super);
    function ResourceType() {
        _super.apply(this, arguments);
        this.$name = [MetaModel.key(), MetaModel.description("Name of the resource type")];
        this.$usage = [MetaModel.description("Instructions on how and when the resource type should be used.")];
        this.$ = [MetaModel.inlinedTemplates(), MetaModel.allowQuestion()];
        this.$uses = [
            MetaModel.embeddedInMaps(),
            MetaModel.description("You may import library locally here it contents is accessible only inside of this resource type"),
            MetaModel.setsContextValue("decls", "true"),
            MetaModel.valueDescription("An array of libraries")
        ];
        this.$parametrizedProperties = [
            MetaModel.customHandling(),
            MetaModel.description("Returns object representation of parametrized properties of the resource type")
        ];
    }
    return ResourceType;
})(ResourceBase);
exports.ResourceType = ResourceType;
var ResourceTypeOrTrait = (function () {
    function ResourceTypeOrTrait() {
        this.$usage = [
            MetaModel.description("Instructions on how and when to use this resource type in a RAML spec"),
            MetaModel.valueDescription("Markdown string")
        ];
        this.$uses = [
            MetaModel.embeddedInMaps(),
            MetaModel.description("You may import library locally here it contents is accessible only inside of this trait"),
            MetaModel.valueDescription("An array of libraries")
        ];
        this.$parameters = [
            MetaModel.description("Optional declaration of the parameters that the resource type employs."),
            MetaModel.valueDescription("An object whose property names are the parameter names and whose property values describe the parameter data types.")
        ];
    }
    return ResourceTypeOrTrait;
})();
exports.ResourceTypeOrTrait = ResourceTypeOrTrait;
var Method = (function (_super) {
    __extends(Method, _super);
    function Method() {
        _super.apply(this, arguments);
        this.$method = [MetaModel.key(),
            MetaModel.extraMetaKey("methods"),
            MetaModel.oneOf(["get", "put", "post", "delete", "options", "head", "patch", "trace", "connect"]),
            MetaModel.description("Method that can be called"),
            MetaModel.hide()
        ];
        this.$displayName = [MetaModel.description("An alternate, human-friendly name for the method (in the resource's context).")];
        this.$description = [
            MetaModel.description("A longer, human-friendly description of the method (in the resource's context)"),
            MetaModel.valueDescription("Markdown string")
        ];
        this.$queryString = [
            MetaModel.description("Specifies the query string needed by this method. Mutually exclusive with queryParameters."),
            MetaModel.valueDescription("Type name or type declaration")
        ];
        this.$queryParameters = [
            MetaModel.description("Detailed information about any query parameters needed by this method. Mutually exclusive with queryString."),
            MetaModel.valueDescription("Object whose property names are the query parameter names and whose values describe the values.")
        ];
        this.$headers = [
            MetaModel.description("Detailed information about any request headers needed by this method."),
            MetaModel.valueDescription("Object whose property names are the request header names and whose values describe the values.")
        ];
        this.$body = [
            MetaModel.description("Some methods admit request bodies, which are described by this property."),
            MetaModel.valueDescription("Object whose properties are either<br>1) media types and whose values are type objects describing the request body for that media type, or<br>2) a type object describing the request body for the default media type specified in the root mediaType property")
        ];
        this.$is = [
            MetaModel.description("A list of the traits to apply to this method. See [[raml-10-spec-applying-resource-types-and-traits|Applying Resource Types and Traits]] section."),
            MetaModel.valueDescription("array, which can contain each of the following elements:<br>* name of unparametrized trait<br>* a key-value pair with trait name as key and a map of trait parameters as value<br>* inline trait declaration<br><br>(or a single element of any above kind)")
        ];
        this.$annotations = [
            MetaModel.markdownDescription("Annotations to be applied to this method. Annotations are any property whose key begins with \"(\" and ends with \")\" and whose name (the part between the beginning and ending parentheses) is a declared annotation name. See the [[raml-10-spec-annotations|section on annotations]].")
        ];
        this.$securedBy = [
            MetaModel.description("The security schemes that apply to this method"),
            MetaModel.valueDescription("Array of security scheme names or a  single security scheme name")
        ];
    }
    return Method;
})(MethodBase);
exports.Method = Method;
var Resource = (function (_super) {
    __extends(Resource, _super);
    function Resource() {
        _super.apply(this, arguments);
        this.$relativeUri = [MetaModel.key(),
            MetaModel.startFrom("/"),
            MetaModel.description("Relative URL of this resource from the parent resource"),
            MetaModel.hide()
        ];
        this.$resources = [
            MetaModel.newInstanceName("New Resource"),
            MetaModel.description("A nested resource is identified as any property whose name begins with a slash (\"/\") and is therefore treated as a relative URI."),
            MetaModel.documentationTableLabel("/&lt;relativeUri&gt;"),
            MetaModel.valueDescription("object describing the nested resource")
        ];
        this.$displayName = [MetaModel.description("An alternate, human-friendly name for the resource.")];
        this.$description = [
            MetaModel.description("A longer, human-friendly description of the resource."),
            MetaModel.valueDescription("Markdown string")
        ];
        this.$annotations = [
            MetaModel.markdownDescription("Annotations to be applied to this resource. Annotations are any property whose key begins with \"(\" and ends with \")\" and whose name (the part between the beginning and ending parentheses) is a declared annotation name. See the [[raml-10-spec-annotations|section on annotations]].")
        ];
    }
    return Resource;
})(ResourceBase);
exports.Resource = Resource;
//# sourceMappingURL=methodsAndResources.js.map